/**
 ******************************************************************************
 * @file    apds9301.c
 * @author  Radek Kysilka
 * @version V1.0.0
 * @date    14-February-2018
 * @brief   This file provides a set of functions needed to manage the LIS2DH12
 *          accelero and gyro devices
 ******************************************************************************
 * @attention
 *
 ******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "apds9301.h"

/** @addtogroup BSP
  * @{
  */

/** @addtogroup Component
  * @{
  */

/** @defgroup APDS9301 APDS9301
  * @{
  */

/** @defgroup APDS9301_Private_Variables APDS9301 Private Variables
  * @{
  */ 
LIGHTSENSE_DrvTypeDef Apds9301LightSensorDrv =
{
  APDS9301_LightSenseInit,
  APDS9301_LightSenseDeInit,
  APDS9301_LightSenseReadID,
  APDS9301_LightSenseLowPower,
  APDS9301_LightSenseRead
};


/**
  * @}
  */ 

/** @defgroup APDS9301_ACC_Private_Functions APDS9301 ACC Private Functions
  * @{
  */
/**
  * @brief  Set APDS9301 Accelerometer Initialization.
  * @param  InitStruct: Init parameters
  * APDS9301_REG_CONTROL (20h) ===> MSB  
  * CTRL_REG4 (23h) ===> LSB  
  */
void APDS9301_LightSenseInit(uint8_t i2caddr, uint16_t InitStruct)
{  
  uint8_t tmp;

  /* Write value */
  tmp = (uint8_t) InitStruct;
  SENSOR_IO_Write(i2caddr, APDS9301_REG_COMMAND | APDS9301_REG_CONTROL, APDS9301_BIT_POWERDOWN);
  SENSOR_IO_Write(i2caddr, APDS9301_REG_COMMAND | APDS9301_REG_CONTROL, tmp);
  tmp = ((uint8_t) (InitStruct >> 8)); 
  SENSOR_IO_Write(i2caddr, APDS9301_REG_COMMAND | APDS9301_REG_TIMING, tmp);
}

/**
  * @brief  APDS9301 Accelerometer De-initialization.
  */
void APDS9301_LightSenseDeInit(uint8_t i2caddr)
{
  uint8_t ctrl = 0x00;
  SENSOR_IO_Write(i2caddr, APDS9301_REG_COMMAND | APDS9301_REG_CONTROL, ctrl);
}

/**
  * @brief  Read APDS9301 ID.
  * @retval ID 
  */
uint8_t APDS9301_LightSenseReadID(uint8_t i2caddr)
{  
  /* IO interface initialization */
  SENSOR_IO_Init();
  /* Read value at Who am I register address */
  return (SENSOR_IO_Read(i2caddr, APDS9301_REG_COMMAND | APDS9301_REG_ID));
}

/**
  * @brief  Set/Unset Accelerometer in low power mode.
  * @param  status 0 means disable Low Power Mode, otherwise Low Power Mode is enabled
  */
void APDS9301_LightSenseLowPower(uint8_t i2caddr, uint16_t status)
{
  uint8_t ctrl = 0x00;

  /* Set Low Power Mode */
  if(status)
  {
    ctrl |= APDS9301_BIT_POWERDOWN;
  }else
  {
    ctrl |= APDS9301_BIT_POWERUP;
  }

  /* write back control register */
  SENSOR_IO_Write(i2caddr, APDS9301_REG_COMMAND | APDS9301_REG_CONTROL, ctrl);
}

/**
  * @brief  Read X, Y & Z Acceleration values 
  * @param  pData: Data out pointer
  */
void APDS9301_LightSenseRead(uint8_t i2caddr, uint16_t* pData)
{
  //int16_t pnRawData[2];
  uint8_t buffer[4];
  uint8_t i = 0;
  
  /* Read the data register content */
  for(i=0; i<4; i++) buffer[i] = SENSOR_IO_Read(i2caddr, APDS9301_REG_COMMAND | (APDS9301_REG_DATA0_LOW + i));
  for(i=0; i<2; i++) pData[i]=((((uint16_t)buffer[2*i+1]) << 8) + (uint16_t)buffer[2*i]);

}


