/**
 ******************************************************************************
 * @file    sht31dis.h
 * @author  ELKYS servis s.r.o. - Radek Kysilka 2019
 * @version V1.0.0
 * @date    14-February-2019
 * @brief   This file provides a set of functions needed to manage the SHT31DIS
 *          humidity and temperature devices
 ******************************************************************************
 * @attention
 *
 * <h2><center>&copy; COPYRIGHT(c) 2017 ELKYS servis s.r.o.</center></h2>
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *   1. Redistributions of source code must retain the above copyright notice,
 *      this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright notice,
 *      this list of conditions and the following disclaimer in the documentation
 *      and/or other materials provided with the distribution.
 *   3. Neither the name of ELKYS servis s.r.o. nor the names of its contributors
 *      may be used to endorse or promote products derived from this software
 *      without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ******************************************************************************
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SHT31DIS__H
#define __SHT31DIS__H

#ifdef __cplusplus
extern "C" {
#endif
  
/* Includes ------------------------------------------------------------------*/
#include "../Common/humsense.h"
#include "../Common/tsense.h"

/** @addtogroup BSP
  * @{
  */

/** @addtogroup Component
  * @{
  */

/** @addtogroup SHT31DIS
  * @{
  */

/** @defgroup SHT31DIS_Exported_Constants SHT31DIS Exported Constants
  * @{
  */

/**
  * @brief  Bitfield positioning.
  */
#define SHT31DIS_BIT(x) ((uint8_t)x)


/**
  * @brief Device Identification register.
  *        Read
  *        Default value: 0xBC
  *        7:0 This read-only register contains the device identifier for SHT31DIS.
  */
#define SHT31DIS_WHO_AM_I_REG          (uint8_t)0x0F	/* there is no register  */

/**
  * @brief Device Identification value.
  */
#define SHT31DIS_WHO_AM_I_VAL         (uint8_t)0xEE		/* virtual return of ID */


// Sensor Commands
typedef enum{
 CMD_READ_SERIALNBR = 0x3780, // read serial number
 CMD_READ_STATUS = 0xF32D, // read status register
 CMD_CLEAR_STATUS = 0x3041, // clear status register
 CMD_HEATER_ENABLE = 0x306D, // enabled heater
 CMD_HEATER_DISABLE = 0x3066, // disable heater
 CMD_SOFT_RESET = 0x30A2, // soft reset
 CMD_MEAS_CLOCKSTR_H = 0x2C06, // measurement: clock stretching, high repeatability
 CMD_MEAS_CLOCKSTR_M = 0x2C0D, // measurement: clock stretching, medium repeatability
 CMD_MEAS_CLOCKSTR_L = 0x2C10, // measurement: clock stretching, low repeatability
 CMD_MEAS_POLLING_H = 0x2400, // measurement: polling, high repeatability
 CMD_MEAS_POLLING_M = 0x240B, // measurement: polling, medium repeatability
 CMD_MEAS_POLLING_L = 0x2416, // measurement: polling, low repeatability
 CMD_MEAS_PERI_05_H = 0x2032, // measurement: periodic 0.5 mps, high repeatability
 CMD_MEAS_PERI_05_M = 0x2024, // measurement: periodic 0.5 mps, medium repeatability
 CMD_MEAS_PERI_05_L = 0x202F, // measurement: periodic 0.5 mps, low repeatability
 CMD_MEAS_PERI_1_H = 0x2130, // measurement: periodic 1 mps, high repeatability
 CMD_MEAS_PERI_1_M = 0x2126, // measurement: periodic 1 mps, medium repeatability
 CMD_MEAS_PERI_1_L = 0x212D, // measurement: periodic 1 mps, low repeatability
 CMD_MEAS_PERI_2_H = 0x2236, // measurement: periodic 2 mps, high repeatability
 CMD_MEAS_PERI_2_M = 0x2220, // measurement: periodic 2 mps, medium repeatability
 CMD_MEAS_PERI_2_L = 0x222B, // measurement: periodic 2 mps, low repeatability
 CMD_MEAS_PERI_4_H = 0x2334, // measurement: periodic 4 mps, high repeatability
 CMD_MEAS_PERI_4_M = 0x2322, // measurement: periodic 4 mps, medium repeatability
 CMD_MEAS_PERI_4_L = 0x2329, // measurement: periodic 4 mps, low repeatability
 CMD_MEAS_PERI_10_H = 0x2737, // measurement: periodic 10 mps, high repeatability
 CMD_MEAS_PERI_10_M = 0x2721, // measurement: periodic 10 mps, medium repeatability
 CMD_MEAS_PERI_10_L = 0x272A, // measurement: periodic 10 mps, low repeatability
 CMD_FETCH_DATA = 0xE000, // readout measurements for periodic mode
 CMD_R_AL_LIM_LS = 0xE102, // read alert limits, low set
 CMD_R_AL_LIM_LC = 0xE109, // read alert limits, low clear
 CMD_R_AL_LIM_HS = 0xE11F, // read alert limits, high set
 CMD_R_AL_LIM_HC = 0xE114, // read alert limits, high clear
 CMD_W_AL_LIM_HS = 0x611D, // write alert limits, high set
 CMD_W_AL_LIM_HC = 0x6116, // write alert limits, high clear
 CMD_W_AL_LIM_LC = 0x610B, // write alert limits, low clear
 CMD_W_AL_LIM_LS = 0x6100, // write alert limits, low set
 CMD_NO_SLEEP = 0x303E,
}SHT31DIS_Commands;


/** @defgroup SHT31DIS_Humidity_Exported_Functions SHT31DIS Humidity Exported Functions
  * @{
  */  
/* HUMIDITY functions */
void SHT31DIS_H_Init(uint16_t DeviceAddr);
uint8_t SHT31DIS_H_ReadID(uint16_t DeviceAddr);
float SHT31DIS_H_ReadHumidity(uint16_t DeviceAddr);
/**
  * @}
  */

/** @defgroup SHT31DIS_HumImported_Globals  Humidity Imported Globals
  * @{
  */
/* Humidity driver structure */
extern HSENSOR_DrvTypeDef SHT31DIS_H_Drv;
/**
  * @}
  */

/** @defgroup SHT31DIS_Temperature_Exported_Functions SHT31DIS Temperature Exported Functions
  * @{
  */
/* TEMPERATURE functions */
void SHT31DIS_T_Init(uint16_t DeviceAddr, TSENSOR_InitTypeDef *pInitStruct);
float SHT31DIS_T_ReadTemp(uint16_t DeviceAddr);
/**
  * @}
  */
  
/** @defgroup SHT31DIS_TempImported_Globals  Temperature Imported Globals
  * @{
  */
/* Temperature driver structure */
extern TSENSOR_DrvTypeDef SHT31DIS_T_Drv;

/**
  * @}
  */

/** @defgroup SHT31DIS_Imported_Functions SHT31DIS Imported Functions
  * @{
  */
/* IO functions */
extern void     SENSOR_IO_Init(void);
extern void     SENSOR_IO_Write(uint8_t Addr, uint8_t Reg, uint8_t Value);
extern uint8_t  SENSOR_IO_Read(uint8_t Addr, uint8_t Reg);
extern uint16_t SENSOR_IO_ReadMultiple(uint8_t Addr, uint8_t Reg, uint8_t *Buffer, uint16_t Length);
extern void     SENSOR_IO_WriteMultiple(uint8_t Addr, uint8_t Reg, uint8_t *Buffer, uint16_t Length);
extern HAL_StatusTypeDef SENSOR_IO_Receive(uint8_t Addr, uint8_t *Buffer, uint16_t Length);
/**
  * @}
  */

#ifdef __cplusplus
}
#endif

#endif /* __SHT31DIS__H */

/**
  * @}
  */
  
/**
  * @}
  */
  
/**
  * @}
  */

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
